<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Ambiente en vivo detectado. Favor seleccione la partición raíz del sistema que desea modificar (solamente muestran particiones Linux)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Está bien</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Usa estructura simplificada de menús sin submenús</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Utiliza menús planos (sin sub-menus)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Inicia al </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Fijar en &apos;0&apos; para iniciar inmediatamente sin mostrar el menú, ó a &apos;-1&apos; para esperar la selección</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Limite de tiempo del Menú</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Parámetros del kernel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Con esta opción habilitada, cualquier entrada seleccionada del menú grub será guardada como predeterminada para futuros inicios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Habilitar el guardado de la última selección de inicio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Administrar las opciones de arranque de UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Fondo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Imagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Activar tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Pantalla de bienvenida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Vista previa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Mensajes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Muy detallada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Detallada (ajuste predeterminado)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Limitada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Desplegar registro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="72"/>
        <source>Still running</source>
        <translation>Aun ejecutando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation>El proceso sigue en ejecución. ¿Seguro que quiere salir?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Set timeout</source>
        <translation>Establecer tiempo de espera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Timeout in seconds:</source>
        <translation>Tiempo de espera en segundos:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <location filename="../mainwindow.cpp" line="421"/>
        <location filename="../mainwindow.cpp" line="1073"/>
        <source>Timeout: %1 seconds</source>
        <translation>Tiempo de espera: %1 segundos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="218"/>
        <location filename="../mainwindow.cpp" line="423"/>
        <location filename="../mainwindow.cpp" line="1072"/>
        <location filename="../mainwindow.cpp" line="1088"/>
        <source>Boot Next: %1</source>
        <translation>Arrancar siguiente: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Removal confirmation</source>
        <translation>Confirmación de eliminación</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>¿Está seguro de que desea eliminar esta entrada de arranque?
%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Select EFI file</source>
        <translation>Seleccionar archivo EFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>Archivos EFI (*.efi *.EFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <location filename="../mainwindow.cpp" line="315"/>
        <location filename="../mainwindow.cpp" line="346"/>
        <location filename="../mainwindow.cpp" line="506"/>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>No se pudo encontrar el punto de montaje de origen para %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Set name</source>
        <translation>Establecer nombre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>Ingrese el nombre para el elemento del menú UEFI:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>Algo salió mal, no se pudo agregar la entrada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Instalando pantalla de bienvenida, favor espere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Updating sources</source>
        <translation>Actualizando recursos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Could not install the bootsplash.</source>
        <translation>No se pudo instalar la pantalla de bienvenida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Boot Current: %1</source>
        <translation>Arranque actual: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Cannot continue</source>
        <translation>No es posible continuar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>No se seleccionó nada; no es posible cambiar opciones de inicio. Saliendo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="507"/>
        <source>Could not create a temporary folder</source>
        <translation>No se pudo crear una carpeta temporal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>No es posible crear ambiente de chroot, imposible cambiar opciones de inicio. Saliendo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>Algo salió mal, no se pudo guardar el orden de inicio.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="767"/>
        <location filename="../mainwindow.cpp" line="1179"/>
        <source>Updating configuration, please wait</source>
        <translation>Actualizando configuración, favor espere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="816"/>
        <source>Updating initramfs...</source>
        <translation>Actualizando initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <location filename="../mainwindow.cpp" line="1191"/>
        <source>Updating grub...</source>
        <translation>Actualizando grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Changes have been successfully applied.</source>
        <translation>Los cambios se han aplicado con éxito. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="842"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa para escoger selecciones comunes de arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="846"/>
        <location filename="../mainwindow.cpp" line="857"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <location filename="../mainwindow.cpp" line="864"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="848"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>MX Boot Options</source>
        <translation>MX Opciones de Inicio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="918"/>
        <source>Running in a Virtual Machine</source>
        <translation>Ejecutando en una Máquina Virtual</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="919"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>El sistema actual se está ejecutando en una Máquina Virtual,
La pantalla de inicio Plymouth funcionará de manera limitada, además no será posible la previsualización del tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="924"/>
        <source>Plymouth packages not installed</source>
        <translation>Paquetes de Plymouth no instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="924"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Los paquetes de Plymouth no están instalados actualmente
¿Está bien instalarlos? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Imágenes (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1047"/>
        <source>Press any key to close</source>
        <translation>Pulse cualquier tecla para cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1049"/>
        <source>Log not found</source>
        <translation>Registro no encontrado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1049"/>
        <source>Could not find log at </source>
        <translation>No se encontró registro en</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1055"/>
        <source>Edit UEFI Boot Entries</source>
        <translation>Editar entradas de arranque UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1058"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>Puede utilizar los botones Arriba/Abajo o arrastrar y soltar elementos para cambiar el orden de arranque.
- Los elementos se enlistan en el orden de arranque. 
- Las líneas atenuadas están inactivas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1061"/>
        <location filename="../mainwindow.cpp" line="1108"/>
        <source>Set ac&amp;tive</source>
        <translation>Establecer ac&amp;tivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1062"/>
        <source>&amp;Add entry</source>
        <translation>&amp;Añadir entrada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1063"/>
        <source>Boot &amp;next</source>
        <translation>Arrancar &amp;siguiente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1064"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1065"/>
        <source>Move &amp;down</source>
        <translation>Mover &amp;abajo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1066"/>
        <source>&amp;Remove entry</source>
        <translation>&amp;Remover entrada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1067"/>
        <source>Re&amp;set next</source>
        <translation>Re&amp;stablecer siguiente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1068"/>
        <source>Change &amp;timeout</source>
        <translation>Cambiar &amp;tiempo de espera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>Move &amp;up</source>
        <translation>Mover &amp;arriba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1072"/>
        <location filename="../mainwindow.cpp" line="1088"/>
        <source>not set, will boot using list order</source>
        <translation>no establecido, se iniciará usando el orden de la lista</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1105"/>
        <source>Set &amp;inactive</source>
        <translation>Establecer &amp;inactivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1157"/>
        <source>Needs reboot</source>
        <translation>Necesita reinciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1157"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Acaba de instalar Plymouth; puede ser necesario reiniciar para mostrar las previsualizaciones </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1212"/>
        <source>Click to select theme</source>
        <translation>Haga clic para seleccionar el tema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa para escoger selecciones comunes de arranque</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que ha iniciado sesión como root, cierre la sesión e inicie sesión como usuario normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="943"/>
        <source>Select image to display in bootloader</source>
        <translation>Seleccionar imagen para mostrar en el cargador de arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1222"/>
        <source>Select GRUB theme</source>
        <translation>Seleccionar tema del GRUB</translation>
    </message>
</context>
</TS>